// Module: PixelList
//
// Author: Hassan Siddiqui
//
// Description: 
// Contains methods for creating a pixel list
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: PixelList.cc,v 1.1 2012/01/25 15:46:31 rsaxton Exp $

/* SAS */
#include "Tracer.h"
#include "Dal.h"
#include "ArrayPixelIterator.h"

/* Local */
#include "PixelList.h"

PixelList::PixelList()
{
  PROC;
  ENDPROC;
}

PixelList::~PixelList()
{
  PROC;
  ENDPROC;
}

/* Convert an array to a pixel list. 
   The pixel list consists of 3 columns,
   axis1, axis2 and value.
   The first two columns denote the pixel INDEX,
   _not_ the physical coordinate value. 
   This is propagated to the WCS attributes of these columns
   from the WCS attributes for the original array.

   The value column stores the value of the array at every pixel.
   
   So for 2x2 array of 10s with the top-right pixel at 0,
   the following column values would be generated:

   AXIS1 AXIS2 VALUE
   1     1     10
   1     2     10
   2     1     0
   2     2     10
*/
void PixelList::arrayToPixelList( const string & arrayname,
				  const string & tablename,
				  const string & axis1,
				  const string & axis2,
				  const string & valuecol)
{
  PROC;

  /* Create an array pixel iterator object */
  ArrayPixelIterator * arrayitr = 
    new ArrayPixelIterator(arrayname);

  /* Create output table */
  DataSet * ods = dataSetServer->open(tablename, Dal::Create);

  Table * table = ods->addTable(tablename, arrayitr->size());

  Column * axis1Col = table->addColumn(axis1, 
				       Column::Int16, 
				       "", 
				       "");
  ColumnData * axis1ColData   = axis1Col->data();
  int16     * axis1Data      = axis1ColData->int16Data();


  Column * axis2Col = table->addColumn(axis2, 
				       Column::Int16, 
				       "", 
				       "");
  ColumnData * axis2ColData   = axis2Col->data();
  int16     * axis2Data      = axis2ColData->int16Data();

  Column * valueCol = table->addColumn(valuecol, 
				       Column::Real32, 
				       "", 
				       "");
  ColumnData * valueColData   = valueCol->data();
  real32     * valueData      = valueColData->real32Data();

  /* Add WCS attributes to the axes columns 
     (for pixel number - physical coord mapping) */
  arrayitr->wcsconvertor()->addAttributesTo(axis1Col, axis2Col);

  int row = 0;
  FOREACH(arrayitr)
    {
      PixelElement pixel = arrayitr->currentItem();
      axis1Data[row]  = pixel.xIndex();
      axis2Data[row]  = pixel.yIndex();
      valueData[row]  = pixel.value();
      ++row;
    }

  delete axis2ColData;
  delete axis1ColData;

  dataSetServer->close(ods);

  ENDPROC;
}
  

