//
// Module: SscWcsConvertor
// Author: Richard Saxton 
//
// Description: Class to access the SSCLIB coordinate conversion routines
//
// Modifications: See ChangeLog
//
//
#ifndef SscWcsConvertor_H
#define SscWcsConvertor_H
//
///* General classes */
#include <iostream>
//
#include "CalServer.h"  // Includes stuff to make F90PROCs work

/* SAS-specific classes */
#include "CoordPair.h"

//
class SscWcsConvertor
{
public:

  /* Constructor */
  SscWcsConvertor();

  /* Destructor */
  ~SscWcsConvertor();

  /* Method: setWcs() - set up the wcs, within ssclib */
  static void setWcs(const string &imagefile);

  /* Method: setWcsRef() - set up the wcs, within ssclib */
  static void setWcsRef(const string &imagefile);

  /* Method: setAtt() - set up the attitude matrices, within ssclib */
  static void setAtt(const string &imagefile);

  /* Method: RaDecToImagePixels - converts from ra/dec to image pixel coords */
  static CoordPair raDecToImagePixels(double ra, double dec);

  /* Method: RaDecToImagePixels - converts from ra/dec to sky (X/Y) coords */
  static CoordPair raDecToSkyPixels(double ra, double dec);

  /* Method: RaDecToDet - converts from ra/dec to detector coords */
  static CoordPair raDecToDet(double ra, double dec);

  /* Method: imagePixelsToRaDec - converts from image pixels to ra/dec */
  static CoordPair imagePixelsToRaDec(double xpixel, double ypixel);

  /* Method: imagePixelsToDet - converts from image to detector pixels */
  static CoordPair imagePixelsToDet(double xpixel, double ypixel);

  /* Method: detToRaDec - converts from detector coords to celestial coords */
  static CoordPair detToRaDec(double detx, double dety);

  /* Method: xyToRaDec - converts from xy to celestial coords */
  static CoordPair xyToRaDec(double x, double y);

  /* Method: xyToDet - converts from xy to detector coords */
  static CoordPair xyToDet(double x, double y);

  /* Method: rawToDet - converts from raw to detector coords */
  static CoordPair rawToDet(double rawx, double rawy);

  /* Method: dettoXy - converts from detector to sky (x/y) coords */
  static CoordPair detToXy(double detx, double dety);

  /* Method: detToTel - converts from detector to theta/phi */
  static CoordPair detToTel(double detx, double dety);

  /* Method: raDecToTel - converts from celestial to theta/phi */
  static CoordPair raDecToTel(double ra, double dec);

  /* Method: detToRaw - converts from detector to raw coords */
  static CoordPair detToRaw(double detx, double dety);

  /* Method: detToCcd - converts from detector to CCD number */
  static Ccd detToCcd(double detx, double dety);

private:


  /* Member fields */

};

#endif

